@@ -100,8 +100,8 @@ ABI_FAR_CALL int abi_plugin_unregister (XAP_ModuleInfo * mi)
 /**
  * 
  */
-ABI_FAR_CALL int abi_plugin_supports_version (UT_uint32 major, UT_uint32 minor, 
-                 UT_uint32 release)
+ABI_FAR_CALL int abi_plugin_supports_version (UT_uint32 /*major*/, UT_uint32 /*minor*/, 
+                 UT_uint32 /*release*/)
 {
   return 1;
 }
