@@ -135,12 +135,9 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
         
     } else if (!strcmp(pName, "text:h" )) {
 
-        const gchar* pStyleName;
-        const gchar* pOutlineLevel;
-        const ODi_Style_Style* pStyle;
-        
-        pStyleName = UT_getAttribute("text:style-name", ppAtts);
-        UT_ASSERT(pStyleName);
+        const gchar* pStyleName = NULL;
+        const gchar* pOutlineLevel = NULL;
+        const ODi_Style_Style* pStyle = NULL;
         
         pOutlineLevel = UT_getAttribute("text:outline-level", ppAtts);
         if (pOutlineLevel == NULL) {
@@ -148,9 +145,11 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
             // be at level 1.
             pOutlineLevel = "1";
         }
-        
-        pStyle = m_pStyles->getParagraphStyle(pStyleName, m_bOnContentStream);
-        UT_ASSERT_HARMLESS(pStyle);
+
+        pStyleName = UT_getAttribute("text:style-name", ppAtts);
+        if (pStyleName) {
+            pStyle = m_pStyles->getParagraphStyle(pStyleName, m_bOnContentStream);
+        }
         
         if (pStyle && (pStyle->isAutomatic())) {
 
@@ -179,13 +178,18 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
         
         const gchar* pSpaceCount;
         UT_uint32 spaceCount, i;
+        UT_sint32 tmpSpaceCount = 0;
         UT_UCS4String string;
         
         pSpaceCount = UT_getAttribute("text:c", ppAtts);
         
-        if (pSpaceCount) {
-            i = sscanf(pSpaceCount, "%d", &spaceCount);
-            UT_ASSERT(i==1);
+        if (pSpaceCount && *pSpaceCount) {
+            i = sscanf(pSpaceCount, "%d", &tmpSpaceCount);
+            if ((i != 1) || (tmpSpaceCount <= 1)) {
+                spaceCount = 1;
+            } else {
+                spaceCount = tmpSpaceCount;
+            }
         } else {
             // From the OpenDocument specification:
             // "A missing text:c attribute is interpreted as meaning a
@@ -449,9 +453,8 @@ void ODi_TextContent_ListenerState::startElement (const gchar* pName,
             const gchar* pVal;
             
             pVal = UT_getAttribute("text:anchor-type", ppAtts);
-            UT_ASSERT(pVal);
             
-            if (pVal && (!strcmp(pVal, "as-char") || !strcmp(pVal, "char"))) {
+            if (!pVal || !strcmp(pVal, "as-char") || !strcmp(pVal, "char")) {
                 _flush();
                 rAction.pushState("Frame");
             } else {
@@ -1028,7 +1031,10 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* /*pName
 
         if (pStyleName) {
             pStyle = m_pStyles->getParagraphStyle(pStyleName, m_bOnContentStream);
-            UT_ASSERT(pStyle);
+
+            if (!pStyle) {
+                pStyle = m_pStyles->getTextStyle(pStyleName, m_bOnContentStream);
+            }
             
             // Damn, use the default style
             if (!pStyle) {
@@ -1259,7 +1265,10 @@ void ODi_TextContent_ListenerState::_endParagraphElement (
                     
     if (pStyleName) {
         pStyle = m_pStyles->getParagraphStyle(pStyleName, m_bOnContentStream);
-        UT_ASSERT(pStyle);
+
+        if (!pStyle) {
+            pStyle = m_pStyles->getTextStyle(pStyleName, m_bOnContentStream);
+        }
         
         // Damn, use the default style
         if (!pStyle) {
