@@ -20,20 +20,30 @@
  * 02111-1307, USA.
  */
 
-#include "OXMLi_ListenerState_Common.h"
-#include <cstring>
-#include <ut_units.h>
-#include <ut_misc.h>
-#include <ut_debugmsg.h>
+// Class definition include
+#include <OXMLi_ListenerState_Common.h>
+
+// Internal includes
+#include <OXMLi_Types.h>
+#include <OXMLi_PackageManager.h>
 #include <OXML_Document.h>
 #include <OXML_Element.h>
 #include <OXML_Element_Run.h>
 #include <OXML_Element_Text.h>
-#include <OXMLi_Types.h>
 #include <OXML_Types.h>
 #include <OXML_Theme.h>
+#include <OXML_Style.h>
+#include <OXML_Section.h>
 #include <OXML_FontManager.h>
 
+// AbiWord includes
+#include <ut_units.h>
+#include <ut_misc.h>
+#include <ut_debugmsg.h>
+
+// External includes
+#include <cstring>
+
 OXMLi_ListenerState_Common::OXMLi_ListenerState_Common() : 
 	OXMLi_ListenerState(), 
 	m_pendingSectBreak(false)
@@ -62,6 +72,17 @@ void OXMLi_ListenerState_Common::startElement (OXMLi_StartElementRequest * rqst)
 
 		rqst->handled = true;
 
+	} else if (!strcmp(rqst->pName, "sectPr")) {
+		//Verify the context...
+		std::string contextTag = rqst->context->back();
+		if (!contextTag.compare("pPr") || !contextTag.compare("body")) {
+			OXML_SharedElement dummy(new OXML_Element("Dummy", P_TAG, BLOCK));
+			rqst->stck->push(dummy);
+
+			m_pendingSectBreak = true;
+			rqst->handled = true;
+		}
+
 /********************************
  ****  PARAGRAPH FORMATTING  ****
  ********************************/
@@ -77,7 +98,10 @@ void OXMLi_ListenerState_Common::startElement (OXMLi_StartElementRequest * rqst)
 
 		if (!strcmp(rqst->pName, "jc")) {
 			const gchar * val = UT_getAttribute("w:val", rqst->ppAtts);
-			UT_return_if_fail( _error_if_fail(val != NULL) );
+
+			if (!val || !*val)
+				return;
+
 			if (!strcmp(val, "left")) {
 				UT_return_if_fail( _error_if_fail( UT_OK == para->setProperty("text-align", "left") ));
 			} else if (!strcmp(val, "center")) {
@@ -350,6 +374,90 @@ void OXMLi_ListenerState_Common::startElement (OXMLi_StartElementRequest * rqst)
 
 /******* END OF RUN FORMATTING ********/
 
+/******************************
+ ****  SECTION FORMATTING  ****
+ ******************************/
+
+	} else if (	!strcmp(rqst->pName, "type") ||
+				!strcmp(rqst->pName, "footerReference") ||
+				!strcmp(rqst->pName, "headerReference")) {
+		//Verify the context...
+		std::string contextTag = rqst->context->back();
+		if (!contextTag.compare("sectPr")) {
+			if (!strcmp(rqst->pName, "type")) {
+				const gchar * val = UT_getAttribute("w:val", rqst->ppAtts);
+				UT_return_if_fail( this->_error_if_fail(val != NULL) );
+
+				OXML_SharedSection last = OXML_Document::getCurrentSection();
+				if (!strcmp(val, "continuous")) {
+					last->setBreakType(CONTINUOUS_BREAK);
+				} else if (!strcmp(val, "evenPage")) {
+					last->setBreakType(EVENPAGE_BREAK);
+				} else if (!strcmp(val, "oddPage")) {
+					last->setBreakType(ODDPAGE_BREAK);
+				} else { //nextPage and nextColumn
+					last->setBreakType(NEXTPAGE_BREAK);
+				}
+				rqst->handled = true;
+
+			} else if (!strcmp(rqst->pName, "footerReference")) {
+				const gchar * id = UT_getAttribute("r:id", rqst->ppAtts);
+				UT_return_if_fail( this->_error_if_fail(id != NULL) );
+				OXML_SharedSection last = OXML_Document::getCurrentSection();
+
+				OXMLi_PackageManager * mgr = OXMLi_PackageManager::getInstance();
+				UT_return_if_fail( _error_if_fail( UT_OK == mgr->parseDocumentHdrFtr(id) ) );
+
+				OXML_Document * doc = OXML_Document::getInstance();
+				UT_return_if_fail(_error_if_fail(doc != NULL));
+				const gchar * type = UT_getAttribute("w:type", rqst->ppAtts);
+				UT_return_if_fail( this->_error_if_fail(type != NULL) );
+
+				if (!strcmp(type, "default")) {
+					last->setFooterId(id, DEFAULT_HDRFTR);
+					type = "footer";
+				} else if (!strcmp(type, "even")) {
+					last->setFooterId(id, EVENPAGE_HDRFTR);
+					type = "footer-even";
+				} else {
+					last->setFooterId(id, FIRSTPAGE_HDRFTR);
+					type = "footer-first";
+				}
+
+				OXML_SharedSection ftr = doc->getFooter(id);
+				UT_return_if_fail(_error_if_fail( UT_OK == ftr->setAttribute("type", type) ));
+
+			} else if (!strcmp(rqst->pName, "headerReference")) {
+				const gchar * id = UT_getAttribute("r:id", rqst->ppAtts);
+				UT_return_if_fail( this->_error_if_fail(id != NULL) );
+				OXML_SharedSection last = OXML_Document::getCurrentSection();
+
+				OXMLi_PackageManager * mgr = OXMLi_PackageManager::getInstance();
+				UT_return_if_fail( _error_if_fail( UT_OK == mgr->parseDocumentHdrFtr(id) ) );
+
+				OXML_Document * doc = OXML_Document::getInstance();
+				UT_return_if_fail(_error_if_fail(doc != NULL));
+				const gchar * type = UT_getAttribute("w:type", rqst->ppAtts);
+				UT_return_if_fail( this->_error_if_fail(type != NULL) );
+
+				if (!strcmp(type, "default")) {
+					last->setHeaderId(id, DEFAULT_HDRFTR);
+					type = "header";
+				} else if (!strcmp(type, "even")) {
+					last->setHeaderId(id, EVENPAGE_HDRFTR);
+					type = "header-even";
+				} else {
+					last->setHeaderId(id, FIRSTPAGE_HDRFTR);
+					type = "header-first";
+				}
+
+				OXML_SharedSection hdr = doc->getHeader(id);
+				UT_return_if_fail(_error_if_fail( UT_OK == hdr->setAttribute("type", type) ));
+			}
+		}
+
+/******* END OF SECTION FORMATTING ********/
+
 	} else if (!strcmp(rqst->pName, "tab")) {
 		//Verify the context...
 		std::string contextTag = rqst->context->back();
@@ -363,12 +471,14 @@ void OXMLi_ListenerState_Common::startElement (OXMLi_StartElementRequest * rqst)
 		
 	} else if (!strcmp(rqst->pName, "br")) {
 		const gchar * type = UT_getAttribute("w:type", rqst->ppAtts);
-		UT_return_if_fail( this->_error_if_fail(type != NULL) );
+// The optional attribute can be missing. In that case a default 
+// value is implied.
+//		UT_return_if_fail( this->_error_if_fail(type != NULL) );
 
 		OXML_ElementTag tag;
-		if (!strcmp(type, "column")) {
+		if (type && !strcmp(type, "column")) {
 			tag = CL_BREAK;
-		} else if (!strcmp(type, "page")) {
+		} else if (type && !strcmp(type, "page")) {
 			tag = PG_BREAK;
 		} else { //textWrapping
 			tag = LN_BREAK;
@@ -377,36 +487,6 @@ void OXMLi_ListenerState_Common::startElement (OXMLi_StartElementRequest * rqst)
 		rqst->stck->push(br);
 
 		rqst->handled = true;
-
-	} else if (!strcmp(rqst->pName, "sectPr")) {
-		//Verify the context...
-		std::string contextTag = rqst->context->back();
-		if (!contextTag.compare("pPr") || !contextTag.compare("body")) {
-			OXML_SharedElement dummy(new OXML_Element("Dummy", P_TAG, BLOCK));
-			rqst->stck->push(dummy);
-
-			m_pendingSectBreak = true;
-			rqst->handled = true;
-		}
-	} else if (!strcmp(rqst->pName, "type")) {
-		//Verify the context...
-		std::string contextTag = rqst->context->back();
-		if (!contextTag.compare("sectPr")) {
-			const gchar * val = UT_getAttribute("w:val", rqst->ppAtts);
-			UT_return_if_fail( this->_error_if_fail(val != NULL) );
-
-			OXML_SharedSection last = OXML_Document::getCurrentSection();
-			if (!strcmp(val, "continuous")) {
-				last->setBreakType(CONTINUOUS_BREAK);
-			} else if (!strcmp(val, "evenPage")) {
-				last->setBreakType(EVENPAGE_BREAK);
-			} else if (!strcmp(val, "oddPage")) {
-				last->setBreakType(ODDPAGE_BREAK);
-			} else { //nextPage and nextColumn
-				last->setBreakType(NEXTPAGE_BREAK);
-			}
-			rqst->handled = true;
-		}
 	}
 }
 
@@ -441,32 +521,6 @@ void OXMLi_ListenerState_Common::endElement (OXMLi_EndElementRequest * rqst)
 		//Run is done, appending it.
 		UT_return_if_fail( this->_error_if_fail( UT_OK == _flushTopLevel(rqst->stck) ) );
 
-		rqst->handled = true;
-	} else if (	!strcmp(rqst->pName, "jc") || 
-				!strcmp(rqst->pName, "ind") ||
-				!strcmp(rqst->pName, "spacing") ) {
-		rqst->handled = true;
-	} else if (	!strcmp(rqst->pName, "b") || 
-				!strcmp(rqst->pName, "i") || 
-				!strcmp(rqst->pName, "u") ||
-				!strcmp(rqst->pName, "color") ||
-				!strcmp(rqst->pName, "highlight") ||
-				!strcmp(rqst->pName, "strike") ||
-				!strcmp(rqst->pName, "dstrike") ||
-				!strcmp(rqst->pName, "rFonts") ||
-				!strcmp(rqst->pName, "lang") ||
-				!strcmp(rqst->pName, "noProof") ||
-				!strcmp(rqst->pName, "vanish") ||
-				!strcmp(rqst->pName, "sz") ) {
-		rqst->handled = true;
-	} else if (!strcmp(rqst->pName, "tab")) {
-		std::string contextTag = rqst->context->back();
-		if (!contextTag.compare("r")) {
-			UT_return_if_fail( this->_error_if_fail( UT_OK == _flushTopLevel(rqst->stck) ) );
-			rqst->handled = true;
-		}
-	} else if (!strcmp(rqst->pName, "br")) {
-		UT_return_if_fail( this->_error_if_fail( UT_OK == _flushTopLevel(rqst->stck) ) );
 		rqst->handled = true;
 	} else if (!strcmp(rqst->pName, "sectPr")) {
 		std::string contextTag = rqst->context->back();
@@ -486,11 +540,39 @@ void OXMLi_ListenerState_Common::endElement (OXMLi_EndElementRequest * rqst)
 
 			rqst->handled = true;
 		}
-	} else if (!strcmp(rqst->pName, "type")) {
+	} else if (	!strcmp(rqst->pName, "jc") || 
+				!strcmp(rqst->pName, "ind") ||
+				!strcmp(rqst->pName, "spacing") ) {
+		rqst->handled = true;
+	} else if (	!strcmp(rqst->pName, "b") || 
+				!strcmp(rqst->pName, "i") || 
+				!strcmp(rqst->pName, "u") ||
+				!strcmp(rqst->pName, "color") ||
+				!strcmp(rqst->pName, "highlight") ||
+				!strcmp(rqst->pName, "strike") ||
+				!strcmp(rqst->pName, "dstrike") ||
+				!strcmp(rqst->pName, "rFonts") ||
+				!strcmp(rqst->pName, "lang") ||
+				!strcmp(rqst->pName, "noProof") ||
+				!strcmp(rqst->pName, "vanish") ||
+				!strcmp(rqst->pName, "sz") ) {
+		rqst->handled = true;
+	} else if (	!strcmp(rqst->pName, "type") ||
+				!strcmp(rqst->pName, "footerReference") ||
+				!strcmp(rqst->pName, "headerReference")) {
 		std::string contextTag = rqst->context->back();
 		if (!contextTag.compare("sectPr")) {
 			rqst->handled = true;
 		}
+	} else if (!strcmp(rqst->pName, "tab")) {
+		std::string contextTag = rqst->context->back();
+		if (!contextTag.compare("r")) {
+			UT_return_if_fail( this->_error_if_fail( UT_OK == _flushTopLevel(rqst->stck) ) );
+			rqst->handled = true;
+		}
+	} else if (!strcmp(rqst->pName, "br")) {
+		UT_return_if_fail( this->_error_if_fail( UT_OK == _flushTopLevel(rqst->stck) ) );
+		rqst->handled = true;
 	}
 }
 
@@ -505,19 +587,3 @@ void OXMLi_ListenerState_Common::charData (OXMLi_CharDataRequest * rqst)
 	UT_return_if_fail( this->_error_if_fail( UT_OK == elem->appendElement(char_data) ) );
 }
 
-void OXMLi_ListenerState_Common::getFontLevelRange(const gchar * val, OXML_FontLevel& level, OXML_CharRange& range)
-{
-	if (NULL != strstr(val, "major")) {
-		level = MAJOR_FONT;
-	} else {
-		level = MINOR_FONT;
-	}
-	if (NULL != strstr(val, "Bidi")) {
-		range = COMPLEX_RANGE;
-	} else if (NULL != strstr(val, "EastAsia")) {
-		range = EASTASIAN_RANGE;
-	} else {
-		range = ASCII_RANGE;
-	}
-}
-
