@@ -113,6 +113,8 @@ IE_Imp_WML::~IE_Imp_WML()
 
 IE_Imp_WML::IE_Imp_WML (PD_Document * pDocument) :
 	IE_Imp_XML(pDocument,false),
+	m_bOpenedBlock(false),
+	m_bOpenedSection(false),
 	m_iColumns(0),
 	m_iImages(0),
 	m_iOpenedColumns(0),
@@ -310,6 +312,7 @@ void IE_Imp_WML::startElement(const gchar *name,
 		// Keep this appendStrux() call here to support files with more
 		// than one <card>
 		X_CheckError(appendStrux(PTX_Section,static_cast<const gchar **>(NULL)));
+		m_bOpenedSection = true;
 		return;
 	}
 
@@ -417,6 +420,7 @@ void IE_Imp_WML::startElement(const gchar *name,
 		}
 
 		X_CheckError(appendStrux(PTX_Block, (left ? NULL : const_cast<const gchar **>(buf))));
+		m_bOpenedBlock = true;
 		return;
 	}
 		
@@ -425,7 +429,10 @@ void IE_Imp_WML::startElement(const gchar *name,
 		X_CheckError((m_parseState == _PS_Block) || (m_parseState == _PS_Cell) || (m_parseState == _PS_Sec));
 
 		if(m_parseState == _PS_Sec)
+		{
 			X_CheckError(appendStrux(PTX_Block,NULL));
+			m_bOpenedBlock = true;
+		}
 
 		const gchar *p_val = NULL;
 		p_val = _getXMLPropValue(static_cast<const gchar *>("src"), atts);
@@ -621,6 +628,13 @@ void IE_Imp_WML::endElement(const gchar *name)
 	case TT_DOCUMENT:
 	{
 		X_VerifyParseState(_PS_Doc);
+
+		if(!m_bOpenedSection)
+		{
+			X_CheckError(appendStrux(PTX_Section, NULL));
+			X_CheckError(appendStrux(PTX_Block, NULL));
+		}
+
 		m_parseState = _PS_Init;
 		return;
 	}
@@ -629,6 +643,12 @@ void IE_Imp_WML::endElement(const gchar *name)
 	{
 		X_VerifyParseState(_PS_Sec);
 		m_parseState = _PS_Doc;
+
+		if(!m_bOpenedBlock)
+			X_CheckError(appendStrux(PTX_Block, NULL));
+
+		m_bOpenedBlock = false;
+
 		return;
 	}
 
@@ -813,7 +833,7 @@ void IE_Imp_WML::createImage(const char *name, const gchar **atts)
 
 	p_val = _getXMLPropValue("xml:lang", atts);
 
-	if(p_val)
+	if(p_val && *p_val)
 	{
 		if(props.length())
 			props+= "; ";
